<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 11/04/2009 *
 * ===================                          Last change: 11/04/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : network_functions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Functions for ext-network                        *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Funktionen fuer ext-network                      *
 * -------------------------------------------------------------------- *
 * $Revision:: 1194                                                   $ *
 * $Date:: 2009-10-27 18:24:18 +0100 (Tue, 27 Oct 2009)               $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author:: quix0r                                                   $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Processes an admin form
function doAdminNetworkProcessForm () {
	// Form really sent?
	if ((!isFormSent()) && (!isPostRequestElementSet('edit')) && (!isPostRequestElementSet('del')) && (!isPostRequestElementSet('change')) && (!isPostRequestElementSet('remove'))) {
		// Abort here
		loadTemplate('admin_settings_saved', false, getMessage('ADMIN_NETWORK_FORM_NOT_SENT'));
		return;
	} elseif (!isGetRequestElementSet('do')) {
		// No 'do' found
		loadTemplate('admin_settings_saved', false, getMessage('ADMIN_NETWORK_DO_404'));
		return;
	}

	// Create function name
	$functionName = sprintf("doAdminNetworkProcess%sForm", ucfirst(strtolower(getRequestElement('do'))));

	// Is the function valid?
	if (!function_exists($functionName)) {
		// Invalid function name
		debug_report_bug('Invalid do ' . getRequestElement('do') . ', function ' . $functionName .' does not exist.');
	} // END - if

	// Call-back the method handling our request
	call_user_func($functionName);
}

// Checks wether the (short) network name is already used (valid)
function isNetworkNameValid ($name) {
	// Query for it
	$result = SQL_QUERY_ESC("SELECT `network_id` FROM `{?_MYSQL_PREFIX?}_network_data` WHERE `network_short_name`='%s' LIMIT 1",
		array($name), __FUNCTION__, __LINE__);

	// Does it exist?
	$isValid = (SQL_NUMROWS($result) == 1);

	// Free result
	SQL_FREERESULT($result);

	// Return result
	return $isValid;
}

// "Getter" for a network's data by provided id number
function getNetworkDataById ($id) {
	// Ids lower one are not accepted
	if ($id < 1) {
		// Not good, should be fixed
		debug_report_bug('Network id ' . $id . ' is smaller than 1.');
	} // END - if

	// By default we have no data
	$networkData = array();

	// Query for the network data
	$result = SQL_QUERY_ESC("SELECT
	`network_id`, `network_short_name`, `network_title`, `network_reflink`, `network_data_seperator`, `network_row_seperator`, `network_request_type`, `network_charset`
FROM
	`{?_MYSQL_PREFIX?}_network_data`
WHERE
	`network_id`=%s
LIMIT 1",
		array(bigintval($id)), __FUNCTION__, __LINE__);

	// Do we have an entry?
	if (SQL_NUMROWS($result) == 1) {
		// Then get it
		$networkData = SQL_FETCHARRAY($result);
	} // END - if

	// Free result
	SQL_FREERESULT($result);

	// Return result
	return $networkData;
}

//------------------------------------------------------------------------------
//                             Call-back functions
//------------------------------------------------------------------------------

// Callback function to add new network
function doAdminNetworkProcessAddnetworkForm () {
	// We can say here, the form is sent, so check if the network is already added
	if (isNetworkNameValid(postRequestElement('network_short_name'))) {
		// Already there
		loadTemplate('admin_settings_saved', false, sprintf(getMessage('ADMIN_NETWORK_ALREADY_ADDED'), postRequestElement('network_short_name')));
		return;
	} // END - if

	// Remove the 'ok' part
	unsetPostRequestElement('ok');

	// Add the whole request to database
	SQL_QUERY("INSERT INTO
	`{?_MYSQL_PREFIX?}_network_data`
(
	`" . implode('`,`', array_keys(postRequestArray())) . "`
) VALUES (
	'" . implode("','", array_values(postRequestArray())) . "'
)", __FUNCTION__, __LINE__);

	// Add the id for output only
	setRequestPostElement('network_id', SQL_INSERTID());

	// Output message
	if (SQL_AFFECTEDROWS() == 1) {
		// Successfully added
		loadTemplate('admin_network_added', false, postRequestArray());
	} else {
		// Not added
		loadTemplate('admin_settings_saved', false, sprintf(getMessage('ADMIN_NETWORK_DATA_NOT_ADDED'), postRequestElement('network_short_name')));
	}
}

// Displays selected networks for editing
function doAdminNetworkProcessHandlenetworkForm () {
	// Do we have selections?
	if (countPostSelection() > 0) {
		// Something has been selected, so start displaying one by one
		$SW = 2; $OUT = '';
		foreach (postRequestElement('sel') as $id=>$sel) {
			// Is this selected?
			if ($sel == 1) {
				// Load this network's data
				$networkData = getNetworkDataById($id);

				// Do we have found the network?
				if (count($networkData) > 0) {
					// Add color
					$networkData['sw'] = $SW;

					// Make selection box for network_request_type
					$networkData['network_request_type'] = generateOptionList(
						'/ARRAY/',
						array('GET','POST'),
						array(getMessage('ADMIN_NETWORK_REQUEST_TYPE_GET'), getMessage('ADMIN_NETWORK_REQUEST_TYPE_POST')),
						$networkData['network_request_type']
					);

					// Add row template and switch color
					$OUT .= loadTemplate('admin_edit_networks_row', true, $networkData);
					$SW = 3 - $SW;
				} // END - if
			} // END - if
		} // END - foreach

		// If we have no rows, we don't need to display the edit form
		if (!empty($OUT)) {
			// Output main template
			loadTemplate('admin_edit_networks', false, $OUT);

			// Don't display the list/add new form
			$GLOBALS['network_display'] = false;
		} else {
			// Nothing selected/found
			loadTemplate('admin_settings_saved', false, getMessage('ADMIN_NETWORK_NOTHING_FOUND'));
		}
	} // END - if
}

// [EOF]
?>
